==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/pavement/dialogs_cs.lua <==

dialogId("dir-m-rada0", "font_small", "Stuff yourself with your advice.")
dialogStr("Nech si ty rady.")


dialogId("dir-m-rada1", "font_small", "We know that very well.")
dialogStr("To víme i bez tebe.")


dialogId("dir-m-rada2", "font_small", "Get lost.")
dialogStr("Běž se vycpat.")


dialogId("dir-m-rada3", "font_small", "My patience is running out.")
dialogStr("Pomalu mi dochází trpělivost.")


dialogId("dir-m-rada4", "font_small", "Arrgh... I`ll smash it to pieces.")
dialogStr("Grrr... asi ji brzy něčím majznu.")


dialogId("dir-v-rada0", "font_big", "Ignore it, let it talk.")
dialogStr("Nevšímej si jí, ať si tlachá.")


dialogId("dir-v-rada1", "font_big", "Let us think.")
dialogStr("Nech nás v klidu přemýšlet.")


dialogId("dir-v-rada2", "font_big", "This was some advice, again.")
dialogStr("To jsi nám zase poradila.")


dialogId("dir-v-rada3", "font_big", "It's a shame I have no ears. I could plug them.")
dialogStr("Ach jo, škoda že nemám uši. Zacpal bych si je.")


dialogId("dir-v-rada4", "font_big", "I am fed up to my gills with its nonsense.")
dialogStr("Už těch jejích nesmyslů mám po krk.")


dialogId("dir-hs-uvod0", "font_statue", "It would be easiest if you")
dialogStr("Nejjednodušší by bylo")


dialogId("dir-hs-uvod1", "font_statue", "You would be better off if you")
dialogStr("Určitě by pomohlo")


dialogId("dir-hs-uvod2", "font_statue", "It would help you if you")
dialogStr("Možná by nebylo špatné")


dialogId("dir-hs-uvod3", "font_statue", "I have an idea. What if you")
dialogStr("Mám takový nápad. Co zkusit")


dialogId("dir-hs-uvod4", "font_statue", "Sorry to interrupt, but what if you")
dialogStr("Promiňte, že vám do toho mluvím, ale co takhle")


dialogId("dir-hs-konec0", "font_statue", "demolish some wall.")
dialogStr("vybourat nějakou tu zeď.")


dialogId("dir-hs-konec1", "font_statue", "break off a few stones from the wall and plug the holes with them.")
dialogStr("vylomit pár kamenů ze zdi a ucpat ty díry.")


dialogId("dir-hs-konec2", "font_statue", "plug those holes with something so that that hooked steel wouldn`t get stuck there.")
dialogStr("něčím ucpat ty díry, aby vám tam nezapadla ta zahnutá ocel.")


dialogId("dir-hs-konec3", "font_statue", "smash that pillar by the exit.")
dialogStr("rozbít ten sloupek u východu.")


dialogId("dir-hs-konec4", "font_statue", "saw off some of that hooked steel.")
dialogStr("uříznout kus té zahnuté oceli.")


dialogId("dir-hs-konec5", "font_statue", "rearrange the objects so that you can swim out.")
dialogStr("nějak ty předměty přeskládat, abyste mohly odjet z místnosti.")


dialogId("dir-hs-konec6", "font_statue", "solve it somehow and get to the next level.")
dialogStr("celé to nějak vyřešit a pustit se do dalších místností.")


dialogId("dir-hs-konec7", "font_statue", "start to think about it really hard.")
dialogStr("opravdu pořádně se nad tím zamyslet.")


dialogId("dir-hs-konec8", "font_statue", "swim out through that hole on the left.")
dialogStr("nějak zkusit odjet tou dírou nalevo.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/pavement/dialogs_cs.lua <==

dialogId("dir-m-rada0", "font_small", "Stuff yourself with your advice.")
dialogStr("Nech si ty rady.")


dialogId("dir-m-rada1", "font_small", "We know that very well.")
dialogStr("To víme i bez tebe.")


dialogId("dir-m-rada2", "font_small", "Get lost.")
dialogStr("Běž se vycpat.")


dialogId("dir-m-rada3", "font_small", "My patience is running out.")
dialogStr("Pomalu mi dochází trpělivost.")


dialogId("dir-m-rada4", "font_small", "Arrgh... I’ll smash it to pieces.")
dialogStr("Grrr... asi ji brzy něčím majznu.")


dialogId("dir-v-rada0", "font_big", "Ignore it, let it talk.")
dialogStr("Nevšímej si jí, ať si tlachá.")


dialogId("dir-v-rada1", "font_big", "Let us think.")
dialogStr("Nech nás v klidu přemýšlet.")


dialogId("dir-v-rada2", "font_big", "This was some advice, again.")
dialogStr("To jsi nám zase poradila.")


dialogId("dir-v-rada3", "font_big", "It's a shame I have no ears. I could plug them.")
dialogStr("Ach jo, škoda že nemám uši. Zacpal bych si je.")


dialogId("dir-v-rada4", "font_big", "I am fed up to my gills with its nonsense.")
dialogStr("Už těch jejích nesmyslů mám po krk.")


dialogId("dir-hs-uvod0", "font_statue", "It would be easiest if you")
dialogStr("Nejjednodušší by bylo")


dialogId("dir-hs-uvod1", "font_statue", "You would be better off if you")
dialogStr("Určitě by pomohlo")


dialogId("dir-hs-uvod2", "font_statue", "It would help you if you")
dialogStr("Možná by nebylo špatné")


dialogId("dir-hs-uvod3", "font_statue", "I have an idea. What if you")
dialogStr("Mám takový nápad. Co zkusit")


dialogId("dir-hs-uvod4", "font_statue", "Sorry to interrupt, but what if you")
dialogStr("Promiňte, že vám do toho mluvím, ale co takhle")


dialogId("dir-hs-konec0", "font_statue", "demolish some wall.")
dialogStr("vybourat nějakou tu zeď.")


dialogId("dir-hs-konec1", "font_statue", "break off a few stones from the wall and plug the holes with them.")
dialogStr("vylomit pár kamenů ze zdi a ucpat ty díry.")


dialogId("dir-hs-konec2", "font_statue", "plug those holes with something so that that hooked steel wouldn’t get stuck there.")
dialogStr("něčím ucpat ty díry, aby vám tam nezapadla ta zahnutá ocel.")


dialogId("dir-hs-konec3", "font_statue", "smash that pillar by the exit.")
dialogStr("rozbít ten sloupek u východu.")


dialogId("dir-hs-konec4", "font_statue", "saw off some of that hooked steel.")
dialogStr("uříznout kus té zahnuté oceli.")


dialogId("dir-hs-konec5", "font_statue", "rearrange the objects so that you can swim out.")
dialogStr("nějak ty předměty přeskládat, abyste mohly odjet z místnosti.")


dialogId("dir-hs-konec6", "font_statue", "solve it somehow and get to the next level.")
dialogStr("celé to nějak vyřešit a pustit se do dalších místností.")


dialogId("dir-hs-konec7", "font_statue", "start to think about it really hard.")
dialogStr("opravdu pořádně se nad tím zamyslet.")


dialogId("dir-hs-konec8", "font_statue", "swim out through that hole on the left.")
dialogStr("nějak zkusit odjet tou dírou nalevo.")
